interfaces.py
branch450c435d69b9
changeset 1199 7fa66717175b
parent 994 98f19cf755a1
child 1263 01152fffd593
--- a/interfaces.py	Fri Mar 20 15:08:18 2009 +0100
+++ b/interfaces.py	Wed Apr 01 17:25:40 2009 +0200
@@ -246,12 +246,26 @@
         """return content entity"""
 
     def isioc_container(self):
-        """return container entity"""           
+        """return container entity"""
+
+    def isioc_type(self):
+        """return container type (post, BlogPost, MailMessage)"""
+
+    def isioc_replies(self):
+        """return replies items"""       
+
+    def isioc_topics(self):
+        """return topics items"""
             
 class ISiocContainer(Interface):
     """interface for entities (which are container
     in sioc specification) with sioc views"""
 
     def isioc_type(self):
-        """return container type (forum, weblog, mailinglist)"""
+        """return container type (forum, Weblog, MailingList)"""
+
+    def isioc_items(self):
+        """return contained items"""
+
+